# Xi-CAM XPCS

Xi-CAM GUI plugin that facilitates data exploration and visualization for XPCS experiments.


## Installation

The latest build of Xi-cam.XPCS is available on pypi.

```
pip install xicam.XPCS
```

## Resources

For more information about Xi-CAM, see the [main Xi-CAM repository](https://github.com/xi-cam/xi-cam)

## Release Notes

* 1.3.0 - Refactoring; Visualization overhaul, support for FastCCD, 1-time/2-time analysis

